@@ -1,4 +1,5 @@
 """Various utility functions to avoid boilerplate when performing common operations."""
+import base64
 import pathlib
 import sys
 import traceback
@@ -102,3 +103,19 @@ def format_exception(error: Exception, include_traceback: bool = False) -> str:
     else:
         lines = traceback.format_exception_only(error_type, error)
     return "".join(lines)
+
+
+def base64_decode(content: str) -> str:
+    if isinstance(content, str):
+        return base64.b64decode(content.encode("utf-8")).decode("utf-8")
+
+    raise Exception("Unknown content type: " + str(type(content)))
+
+
+def base64_encode(content: Union[bytes, str]) -> str:
+    if isinstance(content, bytes):
+        return base64.b64encode(content).decode("utf-8")
+    if isinstance(content, str):
+        return base64.b64encode(content.encode("utf-8")).decode("utf-8")
+
+    raise Exception("Unknown content type: " + str(type(content)))
